==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/sms/translations/sms_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>SMS Nick</source>
        <translation>Přezdívka SMS</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Program</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Použít vestavěný program na SMS</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Vlastní program na SMS</translation>
    </message>
    <message>
        <source>Use SMS custom string</source>
        <translation>Použít vlastní řetězec SMS</translation>
    </message>
    <message>
        <source>SMS custom string</source>
        <translation>Vlastní řetězec SMS</translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation>Server SMS</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Poslat SMS</translation>
    </message>
    <message>
        <source>SMS T-Mobile.pl Gateway</source>
        <translation>Server T-Mobile.pl SMS</translation>
    </message>
    <message>
        <source>Sponsored</source>
        <translation>Sponzorovaný</translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation>OmnixMultimedia</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>Uživatelovo ID (48xxxxxxxxx)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Check this box if your sms application does not understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
        <translation>Zaškrtněte toto políčko, pokud váš program na práci s sms nepodporuje argumenty: number &amp;message&amp;
Argumenty mají být odděleny mezerami. %k argument je převeden na číslo, %m na zprávu</translation>
    </message>
    <message>
        <source>SMS proxy for built-in application</source>
        <translation>SMS proxy pro vestavěný program</translation>
    </message>
</context>
<context>
    <name>SmsActions</name>
    <message>
        <source>Send SMS...</source>
        <translation>Poslat SMS...</translation>
    </message>
</context>
<context>
    <name>SmsDialog</name>
    <message>
        <source>Send SMS</source>
        <translation>Poslat SMS</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Příjemce</translation>
    </message>
    <message>
        <source>Select automatically</source>
        <translation>Vybrat automaticky</translation>
    </message>
    <message>
        <source>GSM provider</source>
        <translation>Poskytovatel GSM</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Obsah</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Podpis</translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation>Uložit SMS v historii</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Poslat</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>SMS application was not specified. Visit the configuration section</source>
        <translation>Program pro SMS nebyl určen. Navštivte oddíl s nastavením</translation>
    </message>
    <message>
        <source> - Select recipient - </source>
        <translation> - Vybrat příjemce - </translation>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation>Posílá se SMS...</translation>
    </message>
</context>
<context>
    <name>SmsExternalSender</name>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation>Nepodařilo se dát vzniknout procesu potamka. Ověřte, že je program funkční</translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation>Proces skončil neobvykle. SMS nebyla poslána</translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation>SMS poslána</translation>
    </message>
</context>
<context>
    <name>SmsInternalSender</name>
    <message>
        <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
        <translation>Automatický výběr serveru není dostupný. Vyberte, prosím, server SMS ručně.</translation>
    </message>
    <message>
        <source>Signature can&apos;t be empty.</source>
        <translation>Podpis nemůže být prázdný</translation>
    </message>
    <message>
        <source>Detecting gateway...</source>
        <translation>Zjišťuje se brána...</translation>
    </message>
    <message>
        <source>Detected gateway: %1.</source>
        <translation>Zjištěna brána: %1.</translation>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation>Posílá se SMS...</translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation>SMS poslána</translation>
    </message>
</context>
<context>
    <name>SmsTokenReadJob</name>
    <message>
        <source>Invalid paremeters for token read job.</source>
        <translation>Neplatné parametry pro práci čtení symbolu</translation>
    </message>
    <message>
        <source>Downloading token image...</source>
        <translation>Stahuje se obraz symbolu...</translation>
    </message>
    <message>
        <source>Unable to fetch token image.</source>
        <translation>Nelze natáhnout obraz symbolu.</translation>
    </message>
    <message>
        <source>Unable to read token image.</source>
        <translation>Nelze přečíst obraz symbolu.</translation>
    </message>
    <message>
        <source>Waiting for entry of token value...</source>
        <translation>Čeká se na záznam hodnoty symbolu...</translation>
    </message>
    <message>
        <source>No token value provided.</source>
        <translation>Neposkytnuta žádná hodnota symbolu.</translation>
    </message>
    <message>
        <source>Received token value.</source>
        <translation>Přijata hodnota symbolu.</translation>
    </message>
</context>
</TS>

==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/sms/translations/sms_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Program</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Použít vestavěný program na SMS</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Vlastní program na SMS</translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation>Server SMS</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Poslat SMS</translation>
    </message>
    <message>
        <source>SMS T-Mobile.pl Gateway</source>
        <translation>Server T-Mobile.pl SMS</translation>
    </message>
    <message>
        <source>Sponsored</source>
        <translation>Sponzorovaný</translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation>OmnixMultimedia</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>Uživatelovo ID (48xxxxxxxxx)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Check this box if your sms application does not understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
        <translation>Zaškrtněte toto políčko, pokud váš program na práci s sms nepodporuje argumenty: number &amp;message&amp;
Argumenty mají být odděleny mezerami. %k argument je převeden na číslo, %m na zprávu</translation>
    </message>
    <message>
        <source>SMS proxy for built-in application</source>
        <translation>SMS proxy pro vestavěný program</translation>
    </message>
    <message>
        <source>Extras</source>
        <translation>Navíc</translation>
    </message>
    <message>
        <source>Your nick for SMS</source>
        <translation>Vaše přezdívka pro SMS</translation>
    </message>
    <message>
        <source>Use application custom arguments</source>
        <translation>Použíz vlastní argumenty programu</translation>
    </message>
    <message>
        <source>SMS custom arguments</source>
        <translation>Vlastní argumenty SMS</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Chování</translation>
    </message>
</context>
<context>
    <name>SmsActions</name>
    <message>
        <source>Send SMS...</source>
        <translation>Poslat SMS...</translation>
    </message>
</context>
<context>
    <name>SmsDialog</name>
    <message>
        <source>Send SMS</source>
        <translation>Poslat SMS</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Příjemce</translation>
    </message>
    <message>
        <source>Select automatically</source>
        <translation>Vybrat automaticky</translation>
    </message>
    <message>
        <source>GSM provider</source>
        <translation>Poskytovatel GSM</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Obsah</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Podpis</translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation>Uložit SMS v historii</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Poslat</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>SMS application was not specified. Visit the configuration section</source>
        <translation>Program pro SMS nebyl určen. Navštivte oddíl s nastavením</translation>
    </message>
    <message>
        <source> - Select recipient - </source>
        <translation> - Vybrat příjemce - </translation>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation>Posílá se SMS...</translation>
    </message>
</context>
<context>
    <name>SmsExternalSender</name>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation>Nepodařilo se dát vzniknout procesu potamka. Ověřte, že je program funkční</translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation>Proces skončil neobvykle. SMS nebyla poslána</translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation>SMS poslána</translation>
    </message>
</context>
<context>
    <name>SmsInternalSender</name>
    <message>
        <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
        <translation>Automatický výběr serveru není dostupný. Vyberte, prosím, server SMS ručně.</translation>
    </message>
    <message>
        <source>Signature can&apos;t be empty.</source>
        <translation>Podpis nemůže být prázdný</translation>
    </message>
    <message>
        <source>Detecting gateway...</source>
        <translation>Zjišťuje se brána...</translation>
    </message>
    <message>
        <source>Detected gateway: %1.</source>
        <translation>Zjištěna brána: %1.</translation>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation>Posílá se SMS...</translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation>SMS poslána</translation>
    </message>
</context>
<context>
    <name>SmsTokenReadJob</name>
    <message>
        <source>Invalid paremeters for token read job.</source>
        <translation>Neplatné parametry pro práci čtení symbolu</translation>
    </message>
    <message>
        <source>Downloading token image...</source>
        <translation>Stahuje se obraz symbolu...</translation>
    </message>
    <message>
        <source>Unable to fetch token image.</source>
        <translation>Nelze natáhnout obraz symbolu.</translation>
    </message>
    <message>
        <source>Unable to read token image.</source>
        <translation>Nelze přečíst obraz symbolu.</translation>
    </message>
    <message>
        <source>Waiting for entry of token value...</source>
        <translation>Čeká se na záznam hodnoty symbolu...</translation>
    </message>
    <message>
        <source>No token value provided.</source>
        <translation>Neposkytnuta žádná hodnota symbolu.</translation>
    </message>
    <message>
        <source>Received token value.</source>
        <translation>Přijata hodnota symbolu.</translation>
    </message>
</context>
</TS>
